
.. _covariance:

Covariance
==========

.. note::

    This page describes the MaNGA DAP
    :class:`~mangadap.util.covariance.Covariance` object in general
    terms. For its specific use in the DAP for handling spatial
    covariance in the MaNGA datacubes, see :ref:`spatialcovariance`.

.. include:: include/links.rst
.. include:: include/covariance_usage.rst

